// Persistence of Vision Raytracer 2.0
//
// This file defines a few Index of Refractions for various materials
// for sodium light.  Source: College Physics by Arthur L. Kimball, PhD.
// 4th Edition (1923)(!)
// ---------------------------
#declare Flint_Glass_Ior = 1.71
#declare Crown_Glass_Ior = 1.51
#declare Diamond_Ior = 2.47
#declare Water_Ior = 1.33
#declare Air_Ior = 1.000292
